@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import inspect
+import pickle
 
 import polars as pl
 from polars import datatypes
@@ -32,3 +33,10 @@ def test_dtype_temporal_units() -> None:
 
 def test_get_idx_type() -> None:
     assert datatypes.get_idx_type() == datatypes.UInt32
+
+
+def test_dtypes_picklable() -> None:
+    parametric_type = pl.Datetime("ns")
+    singleton_type = pl.Float64
+    assert pickle.loads(pickle.dumps(parametric_type)) == parametric_type
+    assert pickle.loads(pickle.dumps(singleton_type)) == singleton_type
